@@ -1,4 +1,4 @@
-#### $Id: TA.plot.R,v 1.9 2004/02/18 22:08:46 maechler Exp $
+#### $Id: TA.plot.R,v 1.10 2009/11/18 13:38:48 maechler Exp $
 n.plot <-
     function(x, y=NULL, nam = NULL, abbr = n >= 20 || max(nchar(nam))>=8,
              xlab = NULL, ylab = NULL, log = "",
@@ -61,7 +61,7 @@ TA.plot <-
         }
     }
     mk.main <- function() {
-      cal <- if(is.R()) call else get("call", frame = sys.parent())
+      cal <- call ## if(is.R()) call else get("call", frame = sys.parent())
       if(is.null(cal))
         "Tukey-Anscombe plot of ???"
       else {
